==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/JobScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.JobScheduleArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.JobScheduleType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Scheduling properties of a job.
 * @property enabled Whether or not the schedule is enabled.
 * @property endTime Schedule end time.
 * @property interval Value of the schedule's recurring interval, if the ScheduleType is recurring. ISO8601 duration format.
 * @property startTime Schedule start time.
 * @property type Schedule interval type
 */
public data class JobScheduleArgs(
    public val enabled: Output<Boolean>? = null,
    public val endTime: Output<String>? = null,
    public val interval: Output<String>? = null,
    public val startTime: Output<String>? = null,
    public val type: Output<JobScheduleType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.JobScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.JobScheduleArgs =
        com.pulumi.azurenative.sql.inputs.JobScheduleArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .interval(interval?.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [JobScheduleArgs].
 */
@PulumiTagMarker
public class JobScheduleArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var endTime: Output<String>? = null

    private var interval: Output<String>? = null

    private var startTime: Output<String>? = null

    private var type: Output<JobScheduleType>? = null

    /**
     * @param value Whether or not the schedule is enabled.
     */
    @JvmName("niriqidixsntkdvc")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Schedule end time.
     */
    @JvmName("qerpmcbqpanwmfcj")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value Value of the schedule's recurring interval, if the ScheduleType is recurring. ISO8601 duration format.
     */
    @JvmName("ieugcmvxxldaydob")
    public suspend fun interval(`value`: Output<String>) {
        this.interval = value
    }

    /**
     * @param value Schedule start time.
     */
    @JvmName("tbtsflcghcsjycqx")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Schedule interval type
     */
    @JvmName("jkfykbopxmiuwlpd")
    public suspend fun type(`value`: Output<JobScheduleType>) {
        this.type = value
    }

    /**
     * @param value Whether or not the schedule is enabled.
     */
    @JvmName("dptxewbforffhcma")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Schedule end time.
     */
    @JvmName("riarnwxppdpdfoan")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value Value of the schedule's recurring interval, if the ScheduleType is recurring. ISO8601 duration format.
     */
    @JvmName("aswhevvpjutcagpy")
    public suspend fun interval(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value Schedule start time.
     */
    @JvmName("wjrtbyvyarbomehg")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    /**
     * @param value Schedule interval type
     */
    @JvmName("soooqfeskarfntuw")
    public suspend fun type(`value`: JobScheduleType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JobScheduleArgs = JobScheduleArgs(
        enabled = enabled,
        endTime = endTime,
        interval = interval,
        startTime = startTime,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/JobScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.JobScheduleArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.JobScheduleType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Scheduling properties of a job.
 * @property enabled Whether or not the schedule is enabled.
 * @property endTime Schedule end time.
 * @property interval Value of the schedule's recurring interval, if the ScheduleType is recurring. ISO8601 duration format.
 * @property startTime Schedule start time.
 * @property type Schedule interval type
 */
public data class JobScheduleArgs(
    public val enabled: Output<Boolean>? = null,
    public val endTime: Output<String>? = null,
    public val interval: Output<String>? = null,
    public val startTime: Output<String>? = null,
    public val type: Output<JobScheduleType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.JobScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.JobScheduleArgs =
        com.pulumi.azurenative.sql.inputs.JobScheduleArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .interval(interval?.applyValue({ args0 -> args0 }))
            .startTime(startTime?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [JobScheduleArgs].
 */
@PulumiTagMarker
public class JobScheduleArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var endTime: Output<String>? = null

    private var interval: Output<String>? = null

    private var startTime: Output<String>? = null

    private var type: Output<JobScheduleType>? = null

    /**
     * @param value Whether or not the schedule is enabled.
     */
    @JvmName("oprexvehjunamcyn")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Schedule end time.
     */
    @JvmName("rbsjqpsnjfcvymqm")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value Value of the schedule's recurring interval, if the ScheduleType is recurring. ISO8601 duration format.
     */
    @JvmName("eldugbghwhomuwmb")
    public suspend fun interval(`value`: Output<String>) {
        this.interval = value
    }

    /**
     * @param value Schedule start time.
     */
    @JvmName("rurxklkpltjsvaep")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Schedule interval type
     */
    @JvmName("bomnoymlurksebuy")
    public suspend fun type(`value`: Output<JobScheduleType>) {
        this.type = value
    }

    /**
     * @param value Whether or not the schedule is enabled.
     */
    @JvmName("djglhaiuplhxplcw")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Schedule end time.
     */
    @JvmName("cvyskgsbnhdtepro")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value Value of the schedule's recurring interval, if the ScheduleType is recurring. ISO8601 duration format.
     */
    @JvmName("ogdsjcmfmkrdckwh")
    public suspend fun interval(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value Schedule start time.
     */
    @JvmName("uvbxparjqftbjera")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    /**
     * @param value Schedule interval type
     */
    @JvmName("bghlivhscmlvbomq")
    public suspend fun type(`value`: JobScheduleType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JobScheduleArgs = JobScheduleArgs(
        enabled = enabled,
        endTime = endTime,
        interval = interval,
        startTime = startTime,
        type = type,
    )
}
